==> evrete-core-1.2.01-sources.jar: org/evrete/api/Type.java <==
package org.evrete.api;

import java.util.Collection;
import java.util.function.*;

/**
 * <p>
 * The definition of a type which is assigned to every object before it gets
 * into the working memory.
 * </p>
 *
 * @param <T> Java type
 */
public interface Type<T> extends Named, Copyable<Type<T>> {

    Class<T> getJavaType();

    Collection<TypeField> getDeclaredFields();

    /**
     * <p>
     * Returns a declared field with the given name, or null
     * if no such field is found.
     * </p>
     *
     * @param name field name
     * @return a declared field or null
     */
    TypeField getField(String name);


    /**
     * <p>
     * Field declaration with a {@link Function} as value reader.
     * </p>
     *
     * @param name     field name
     * @param type     field value type
     * @param function the function that will be used to read field's value
     * @return newly created field
     */
    TypeField declareField(String name, Class<?> type, Function<T, Object> function);

    default TypeField declareField(final String name, final ToIntFunction<T> function) {
        return declareField(name, int.class, function::applyAsInt);
    }

    default TypeField declareField(final String name, final ToLongFunction<T> function) {
        return declareField(name, long.class, function::applyAsLong);
    }

    default TypeField declareField(final String name, final ToDoubleFunction<T> function) {
        return declareField(name, double.class, function::applyAsDouble);
    }

    default TypeField declareField(final String name, final Predicate<T> function) {
        return declareField(name, boolean.class, function::test);
    }
}

==> evrete-core-1.2.03-sources.jar: org/evrete/api/Type.java <==
package org.evrete.api;

import java.util.Collection;
import java.util.function.*;

/**
 * <p>
 * The definition of a type which is assigned to every object before it gets
 * into the working memory.
 * </p>
 *
 * @param <T> Java type
 */
public interface Type<T> extends Named, Copyable<Type<T>> {

    Class<T> getJavaType();

    Collection<TypeField> getDeclaredFields();

    /**
     * <p>
     * Returns a declared field with the given name, or null
     * if no such field is found or resolved
     * </p>
     *
     * @param name field name
     * @return a declared field or null
     */
    TypeField getField(String name);


    /**
     * <p>
     * Field declaration with a {@link Function} as value reader.
     * </p>
     *
     * @param name     field name
     * @param type     field value type
     * @param function the function that will be used to read field's value
     * @return newly created field
     */
    TypeField declareField(String name, Class<?> type, Function<T, Object> function);

    default TypeField declareField(final String name, final ToIntFunction<T> function) {
        return declareField(name, int.class, function::applyAsInt);
    }

    default TypeField declareField(final String name, final ToLongFunction<T> function) {
        return declareField(name, long.class, function::applyAsLong);
    }

    default TypeField declareField(final String name, final ToDoubleFunction<T> function) {
        return declareField(name, double.class, function::applyAsDouble);
    }

    default TypeField declareField(final String name, final Predicate<T> function) {
        return declareField(name, boolean.class, function::test);
    }
}
